

(install
 (section share)
 (files
   (af.mar as locales/af.mar)
(af_ZA.mar as locales/af_ZA.mar)
(am.mar as locales/am.mar)
(am_ET.mar as locales/am_ET.mar)
(ar.mar as locales/ar.mar)
(ar_AE.mar as locales/ar_AE.mar)
(ar_BH.mar as locales/ar_BH.mar)
(ar_DZ.mar as locales/ar_DZ.mar)
(ar_EG.mar as locales/ar_EG.mar)
(ar_IN.mar as locales/ar_IN.mar)
(ar_IQ.mar as locales/ar_IQ.mar)
(ar_JO.mar as locales/ar_JO.mar)
(ar_KW.mar as locales/ar_KW.mar)
(ar_LB.mar as locales/ar_LB.mar)
(ar_LY.mar as locales/ar_LY.mar)
(ar_MA.mar as locales/ar_MA.mar)
(ar_OM.mar as locales/ar_OM.mar)
(ar_QA.mar as locales/ar_QA.mar)
(ar_SA.mar as locales/ar_SA.mar)
(ar_SD.mar as locales/ar_SD.mar)
(ar_SY.mar as locales/ar_SY.mar)
(ar_TN.mar as locales/ar_TN.mar)
(ar_YE.mar as locales/ar_YE.mar)
(az.mar as locales/az.mar)
(az_AZ.mar as locales/az_AZ.mar)
(be.mar as locales/be.mar)
(be_BY.mar as locales/be_BY.mar)
(bg.mar as locales/bg.mar)
(bg_BG.mar as locales/bg_BG.mar)
(bn.mar as locales/bn.mar)
(bn_IN.mar as locales/bn_IN.mar)
(ca.mar as locales/ca.mar)
(ca_ES.mar as locales/ca_ES.mar)
(ca_ES_PREEURO.mar as locales/ca_ES_PREEURO.mar)
(cs.mar as locales/cs.mar)
(cs_CZ.mar as locales/cs_CZ.mar)
(da.mar as locales/da.mar)
(da_DK.mar as locales/da_DK.mar)
(de.mar as locales/de.mar)
(de_AT.mar as locales/de_AT.mar)
(de_AT_PREEURO.mar as locales/de_AT_PREEURO.mar)
(de_BE.mar as locales/de_BE.mar)
(de_CH.mar as locales/de_CH.mar)
(de_DE.mar as locales/de_DE.mar)
(de_DE_PREEURO.mar as locales/de_DE_PREEURO.mar)
(de_LI.mar as locales/de_LI.mar)
(de_LU.mar as locales/de_LU.mar)
(de_LU_PREEURO.mar as locales/de_LU_PREEURO.mar)
(de__PHONEBOOK.mar as locales/de__PHONEBOOK.mar)
(div.mar as locales/div.mar)
(div_MV.mar as locales/div_MV.mar)
(el.mar as locales/el.mar)
(el_GR.mar as locales/el_GR.mar)
(el_GR_PREEURO.mar as locales/el_GR_PREEURO.mar)
(en.mar as locales/en.mar)
(en_AS.mar as locales/en_AS.mar)
(en_AU.mar as locales/en_AU.mar)
(en_BE.mar as locales/en_BE.mar)
(en_BE_PREEURO.mar as locales/en_BE_PREEURO.mar)
(en_BW.mar as locales/en_BW.mar)
(en_BZ.mar as locales/en_BZ.mar)
(en_CA.mar as locales/en_CA.mar)
(en_GB.mar as locales/en_GB.mar)
(en_GB_EURO.mar as locales/en_GB_EURO.mar)
(en_GU.mar as locales/en_GU.mar)
(en_HK.mar as locales/en_HK.mar)
(en_IE.mar as locales/en_IE.mar)
(en_IE_PREEURO.mar as locales/en_IE_PREEURO.mar)
(en_IN.mar as locales/en_IN.mar)
(en_JM.mar as locales/en_JM.mar)
(en_MH.mar as locales/en_MH.mar)
(en_MP.mar as locales/en_MP.mar)
(en_MT.mar as locales/en_MT.mar)
(en_NZ.mar as locales/en_NZ.mar)
(en_PH.mar as locales/en_PH.mar)
(en_SG.mar as locales/en_SG.mar)
(en_TT.mar as locales/en_TT.mar)
(en_UM.mar as locales/en_UM.mar)
(en_US.mar as locales/en_US.mar)
(en_US_POSIX.mar as locales/en_US_POSIX.mar)
(en_VI.mar as locales/en_VI.mar)
(en_ZA.mar as locales/en_ZA.mar)
(en_ZW.mar as locales/en_ZW.mar)
(eo.mar as locales/eo.mar)
(es.mar as locales/es.mar)
(es_AR.mar as locales/es_AR.mar)
(es_BO.mar as locales/es_BO.mar)
(es_CL.mar as locales/es_CL.mar)
(es_CO.mar as locales/es_CO.mar)
(es_CR.mar as locales/es_CR.mar)
(es_DO.mar as locales/es_DO.mar)
(es_EC.mar as locales/es_EC.mar)
(es_ES.mar as locales/es_ES.mar)
(es_ES_PREEURO.mar as locales/es_ES_PREEURO.mar)
(es_GT.mar as locales/es_GT.mar)
(es_HN.mar as locales/es_HN.mar)
(es_MX.mar as locales/es_MX.mar)
(es_NI.mar as locales/es_NI.mar)
(es_PA.mar as locales/es_PA.mar)
(es_PE.mar as locales/es_PE.mar)
(es_PR.mar as locales/es_PR.mar)
(es_PY.mar as locales/es_PY.mar)
(es_SV.mar as locales/es_SV.mar)
(es_US.mar as locales/es_US.mar)
(es_UY.mar as locales/es_UY.mar)
(es_VE.mar as locales/es_VE.mar)
(es__TRADITIONAL.mar as locales/es__TRADITIONAL.mar)
(et.mar as locales/et.mar)
(et_EE.mar as locales/et_EE.mar)
(eu.mar as locales/eu.mar)
(eu_ES.mar as locales/eu_ES.mar)
(eu_ES_PREEURO.mar as locales/eu_ES_PREEURO.mar)
(fa.mar as locales/fa.mar)
(fa_IN.mar as locales/fa_IN.mar)
(fa_IR.mar as locales/fa_IR.mar)
(fi.mar as locales/fi.mar)
(fi_FI.mar as locales/fi_FI.mar)
(fi_FI_PREEURO.mar as locales/fi_FI_PREEURO.mar)
(fo.mar as locales/fo.mar)
(fo_FO.mar as locales/fo_FO.mar)
(fr.mar as locales/fr.mar)
(fr_BE.mar as locales/fr_BE.mar)
(fr_BE_PREEURO.mar as locales/fr_BE_PREEURO.mar)
(fr_CA.mar as locales/fr_CA.mar)
(fr_CH.mar as locales/fr_CH.mar)
(fr_FR.mar as locales/fr_FR.mar)
(fr_FR_PREEURO.mar as locales/fr_FR_PREEURO.mar)
(fr_LU.mar as locales/fr_LU.mar)
(fr_LU_PREEURO.mar as locales/fr_LU_PREEURO.mar)
(fr_MC.mar as locales/fr_MC.mar)
(ga.mar as locales/ga.mar)
(ga_IE.mar as locales/ga_IE.mar)
(ga_IE_PREEURO.mar as locales/ga_IE_PREEURO.mar)
(gl.mar as locales/gl.mar)
(gl_ES.mar as locales/gl_ES.mar)
(gl_ES_PREEURO.mar as locales/gl_ES_PREEURO.mar)
(gu.mar as locales/gu.mar)
(gu_IN.mar as locales/gu_IN.mar)
(gv.mar as locales/gv.mar)
(gv_GB.mar as locales/gv_GB.mar)
(he.mar as locales/he.mar)
(he_IL.mar as locales/he_IL.mar)
(hi.mar as locales/hi.mar)
(hi_IN.mar as locales/hi_IN.mar)
(hi__DIRECT.mar as locales/hi__DIRECT.mar)
(hr.mar as locales/hr.mar)
(hr_HR.mar as locales/hr_HR.mar)
(hu.mar as locales/hu.mar)
(hu_HU.mar as locales/hu_HU.mar)
(hy.mar as locales/hy.mar)
(hy_AM.mar as locales/hy_AM.mar)
(hy_AM_REVISED.mar as locales/hy_AM_REVISED.mar)
(id.mar as locales/id.mar)
(id_ID.mar as locales/id_ID.mar)
(index.mar as locales/index.mar)
(is.mar as locales/is.mar)
(is_IS.mar as locales/is_IS.mar)
(it.mar as locales/it.mar)
(it_CH.mar as locales/it_CH.mar)
(it_IT.mar as locales/it_IT.mar)
(it_IT_PREEURO.mar as locales/it_IT_PREEURO.mar)
(iw.mar as locales/iw.mar)
(iw_IL.mar as locales/iw_IL.mar)
(ja.mar as locales/ja.mar)
(ja_JP.mar as locales/ja_JP.mar)
(ka.mar as locales/ka.mar)
(ka_GE.mar as locales/ka_GE.mar)
(kk.mar as locales/kk.mar)
(kk_KZ.mar as locales/kk_KZ.mar)
(kl.mar as locales/kl.mar)
(kl_GL.mar as locales/kl_GL.mar)
(kn.mar as locales/kn.mar)
(kn_IN.mar as locales/kn_IN.mar)
(ko.mar as locales/ko.mar)
(ko_KR.mar as locales/ko_KR.mar)
(kok.mar as locales/kok.mar)
(kok_IN.mar as locales/kok_IN.mar)
(kw.mar as locales/kw.mar)
(kw_GB.mar as locales/kw_GB.mar)
(ky.mar as locales/ky.mar)
(ky_KG.mar as locales/ky_KG.mar)
(lt.mar as locales/lt.mar)
(lt_LT.mar as locales/lt_LT.mar)
(lv.mar as locales/lv.mar)
(lv_LV.mar as locales/lv_LV.mar)
(mk.mar as locales/mk.mar)
(mk_MK.mar as locales/mk_MK.mar)
(mn.mar as locales/mn.mar)
(mn_MN.mar as locales/mn_MN.mar)
(mr.mar as locales/mr.mar)
(mr_IN.mar as locales/mr_IN.mar)
(ms.mar as locales/ms.mar)
(ms_BN.mar as locales/ms_BN.mar)
(ms_MY.mar as locales/ms_MY.mar)
(mt.mar as locales/mt.mar)
(mt_MT.mar as locales/mt_MT.mar)
(nb.mar as locales/nb.mar)
(nb_NO.mar as locales/nb_NO.mar)
(nl.mar as locales/nl.mar)
(nl_BE.mar as locales/nl_BE.mar)
(nl_BE_PREEURO.mar as locales/nl_BE_PREEURO.mar)
(nl_NL.mar as locales/nl_NL.mar)
(nl_NL_PREEURO.mar as locales/nl_NL_PREEURO.mar)
(nn.mar as locales/nn.mar)
(nn_NO.mar as locales/nn_NO.mar)
(no.mar as locales/no.mar)
(no_NO.mar as locales/no_NO.mar)
(no_NO_NY.mar as locales/no_NO_NY.mar)
(om.mar as locales/om.mar)
(om_ET.mar as locales/om_ET.mar)
(om_KE.mar as locales/om_KE.mar)
(pa.mar as locales/pa.mar)
(pa_IN.mar as locales/pa_IN.mar)
(pl.mar as locales/pl.mar)
(pl_PL.mar as locales/pl_PL.mar)
(pt.mar as locales/pt.mar)
(pt_BR.mar as locales/pt_BR.mar)
(pt_PT.mar as locales/pt_PT.mar)
(pt_PT_PREEURO.mar as locales/pt_PT_PREEURO.mar)
(ro.mar as locales/ro.mar)
(ro_RO.mar as locales/ro_RO.mar)
(root.mar as locales/root.mar)
(ru.mar as locales/ru.mar)
(ru_RU.mar as locales/ru_RU.mar)
(ru_UA.mar as locales/ru_UA.mar)
(sa.mar as locales/sa.mar)
(sa_IN.mar as locales/sa_IN.mar)
(sh.mar as locales/sh.mar)
(sh_YU.mar as locales/sh_YU.mar)
(sk.mar as locales/sk.mar)
(sk_SK.mar as locales/sk_SK.mar)
(sl.mar as locales/sl.mar)
(sl_SI.mar as locales/sl_SI.mar)
(so.mar as locales/so.mar)
(so_DJ.mar as locales/so_DJ.mar)
(so_ET.mar as locales/so_ET.mar)
(so_KE.mar as locales/so_KE.mar)
(so_SO.mar as locales/so_SO.mar)
(sq.mar as locales/sq.mar)
(sq_AL.mar as locales/sq_AL.mar)
(sr.mar as locales/sr.mar)
(sr_YU.mar as locales/sr_YU.mar)
(sv.mar as locales/sv.mar)
(sv_FI.mar as locales/sv_FI.mar)
(sv_SE.mar as locales/sv_SE.mar)
(sw.mar as locales/sw.mar)
(sw_KE.mar as locales/sw_KE.mar)
(sw_TZ.mar as locales/sw_TZ.mar)
(syr.mar as locales/syr.mar)
(syr_SY.mar as locales/syr_SY.mar)
(ta.mar as locales/ta.mar)
(ta_IN.mar as locales/ta_IN.mar)
(te.mar as locales/te.mar)
(te_IN.mar as locales/te_IN.mar)
(test_1.mar as locales/test_1.mar)
(th.mar as locales/th.mar)
(th_TH.mar as locales/th_TH.mar)
(ti.mar as locales/ti.mar)
(ti_ER.mar as locales/ti_ER.mar)
(ti_ET.mar as locales/ti_ET.mar)
(tr.mar as locales/tr.mar)
(tr_TR.mar as locales/tr_TR.mar)
(tt.mar as locales/tt.mar)
(tt_RU.mar as locales/tt_RU.mar)
(uk.mar as locales/uk.mar)
(uk_UA.mar as locales/uk_UA.mar)
(ur.mar as locales/ur.mar)
(ur_PK.mar as locales/ur_PK.mar)
(uz.mar as locales/uz.mar)
(uz_UZ.mar as locales/uz_UZ.mar)
(vi.mar as locales/vi.mar)
(vi_VN.mar as locales/vi_VN.mar)
(zh.mar as locales/zh.mar)
(zh_CN.mar as locales/zh_CN.mar)
(zh_HK.mar as locales/zh_HK.mar)
(zh_MO.mar as locales/zh_MO.mar)
(zh_SG.mar as locales/zh_SG.mar)
(zh_TW.mar as locales/zh_TW.mar)
(zh_TW_STROKE.mar as locales/zh_TW_STROKE.mar)
(zh__PINYIN.mar as locales/zh__PINYIN.mar)
 ))

(alias
 (name database)
 (deps (glob_files ../database/*.mar)))


(rule
 (targets af.mar)
 (deps    (:x af.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets af_ZA.mar)
 (deps    (:x af_ZA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets am.mar)
 (deps    (:x am.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets am_ET.mar)
 (deps    (:x am_ET.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar.mar)
 (deps    (:x ar.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_AE.mar)
 (deps    (:x ar_AE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_BH.mar)
 (deps    (:x ar_BH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_DZ.mar)
 (deps    (:x ar_DZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_EG.mar)
 (deps    (:x ar_EG.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_IN.mar)
 (deps    (:x ar_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_IQ.mar)
 (deps    (:x ar_IQ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_JO.mar)
 (deps    (:x ar_JO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_KW.mar)
 (deps    (:x ar_KW.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_LB.mar)
 (deps    (:x ar_LB.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_LY.mar)
 (deps    (:x ar_LY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_MA.mar)
 (deps    (:x ar_MA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_OM.mar)
 (deps    (:x ar_OM.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_QA.mar)
 (deps    (:x ar_QA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_SA.mar)
 (deps    (:x ar_SA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_SD.mar)
 (deps    (:x ar_SD.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_SY.mar)
 (deps    (:x ar_SY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_TN.mar)
 (deps    (:x ar_TN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ar_YE.mar)
 (deps    (:x ar_YE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets az.mar)
 (deps    (:x az.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets az_AZ.mar)
 (deps    (:x az_AZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets be.mar)
 (deps    (:x be.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets be_BY.mar)
 (deps    (:x be_BY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets bg.mar)
 (deps    (:x bg.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets bg_BG.mar)
 (deps    (:x bg_BG.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets bn.mar)
 (deps    (:x bn.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets bn_IN.mar)
 (deps    (:x bn_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ca.mar)
 (deps    (:x ca.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ca_ES.mar)
 (deps    (:x ca_ES.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ca_ES_PREEURO.mar)
 (deps    (:x ca_ES_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets cs.mar)
 (deps    (:x cs.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets cs_CZ.mar)
 (deps    (:x cs_CZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets da.mar)
 (deps    (:x da.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets da_DK.mar)
 (deps    (:x da_DK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de.mar)
 (deps    (:x de.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_AT.mar)
 (deps    (:x de_AT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_AT_PREEURO.mar)
 (deps    (:x de_AT_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_BE.mar)
 (deps    (:x de_BE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_CH.mar)
 (deps    (:x de_CH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_DE.mar)
 (deps    (:x de_DE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_DE_PREEURO.mar)
 (deps    (:x de_DE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_LI.mar)
 (deps    (:x de_LI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_LU.mar)
 (deps    (:x de_LU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de_LU_PREEURO.mar)
 (deps    (:x de_LU_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets de__PHONEBOOK.mar)
 (deps    (:x de__PHONEBOOK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets div.mar)
 (deps    (:x div.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets div_MV.mar)
 (deps    (:x div_MV.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets el.mar)
 (deps    (:x el.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets el_GR.mar)
 (deps    (:x el_GR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets el_GR_PREEURO.mar)
 (deps    (:x el_GR_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en.mar)
 (deps    (:x en.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_AS.mar)
 (deps    (:x en_AS.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_AU.mar)
 (deps    (:x en_AU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_BE.mar)
 (deps    (:x en_BE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_BE_PREEURO.mar)
 (deps    (:x en_BE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_BW.mar)
 (deps    (:x en_BW.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_BZ.mar)
 (deps    (:x en_BZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_CA.mar)
 (deps    (:x en_CA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_GB.mar)
 (deps    (:x en_GB.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_GB_EURO.mar)
 (deps    (:x en_GB_EURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_GU.mar)
 (deps    (:x en_GU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_HK.mar)
 (deps    (:x en_HK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_IE.mar)
 (deps    (:x en_IE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_IE_PREEURO.mar)
 (deps    (:x en_IE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_IN.mar)
 (deps    (:x en_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_JM.mar)
 (deps    (:x en_JM.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_MH.mar)
 (deps    (:x en_MH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_MP.mar)
 (deps    (:x en_MP.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_MT.mar)
 (deps    (:x en_MT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_NZ.mar)
 (deps    (:x en_NZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_PH.mar)
 (deps    (:x en_PH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_SG.mar)
 (deps    (:x en_SG.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_TT.mar)
 (deps    (:x en_TT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_UM.mar)
 (deps    (:x en_UM.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_US.mar)
 (deps    (:x en_US.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_US_POSIX.mar)
 (deps    (:x en_US_POSIX.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_VI.mar)
 (deps    (:x en_VI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_ZA.mar)
 (deps    (:x en_ZA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets en_ZW.mar)
 (deps    (:x en_ZW.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets eo.mar)
 (deps    (:x eo.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es.mar)
 (deps    (:x es.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_AR.mar)
 (deps    (:x es_AR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_BO.mar)
 (deps    (:x es_BO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_CL.mar)
 (deps    (:x es_CL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_CO.mar)
 (deps    (:x es_CO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_CR.mar)
 (deps    (:x es_CR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_DO.mar)
 (deps    (:x es_DO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_EC.mar)
 (deps    (:x es_EC.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_ES.mar)
 (deps    (:x es_ES.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_ES_PREEURO.mar)
 (deps    (:x es_ES_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_GT.mar)
 (deps    (:x es_GT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_HN.mar)
 (deps    (:x es_HN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_MX.mar)
 (deps    (:x es_MX.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_NI.mar)
 (deps    (:x es_NI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_PA.mar)
 (deps    (:x es_PA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_PE.mar)
 (deps    (:x es_PE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_PR.mar)
 (deps    (:x es_PR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_PY.mar)
 (deps    (:x es_PY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_SV.mar)
 (deps    (:x es_SV.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_US.mar)
 (deps    (:x es_US.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_UY.mar)
 (deps    (:x es_UY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es_VE.mar)
 (deps    (:x es_VE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets es__TRADITIONAL.mar)
 (deps    (:x es__TRADITIONAL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets et.mar)
 (deps    (:x et.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets et_EE.mar)
 (deps    (:x et_EE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets eu.mar)
 (deps    (:x eu.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets eu_ES.mar)
 (deps    (:x eu_ES.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets eu_ES_PREEURO.mar)
 (deps    (:x eu_ES_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fa.mar)
 (deps    (:x fa.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fa_IN.mar)
 (deps    (:x fa_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fa_IR.mar)
 (deps    (:x fa_IR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fi.mar)
 (deps    (:x fi.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fi_FI.mar)
 (deps    (:x fi_FI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fi_FI_PREEURO.mar)
 (deps    (:x fi_FI_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fo.mar)
 (deps    (:x fo.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fo_FO.mar)
 (deps    (:x fo_FO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr.mar)
 (deps    (:x fr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_BE.mar)
 (deps    (:x fr_BE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_BE_PREEURO.mar)
 (deps    (:x fr_BE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_CA.mar)
 (deps    (:x fr_CA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_CH.mar)
 (deps    (:x fr_CH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_FR.mar)
 (deps    (:x fr_FR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_FR_PREEURO.mar)
 (deps    (:x fr_FR_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_LU.mar)
 (deps    (:x fr_LU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_LU_PREEURO.mar)
 (deps    (:x fr_LU_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets fr_MC.mar)
 (deps    (:x fr_MC.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ga.mar)
 (deps    (:x ga.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ga_IE.mar)
 (deps    (:x ga_IE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ga_IE_PREEURO.mar)
 (deps    (:x ga_IE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gl.mar)
 (deps    (:x gl.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gl_ES.mar)
 (deps    (:x gl_ES.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gl_ES_PREEURO.mar)
 (deps    (:x gl_ES_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gu.mar)
 (deps    (:x gu.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gu_IN.mar)
 (deps    (:x gu_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gv.mar)
 (deps    (:x gv.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets gv_GB.mar)
 (deps    (:x gv_GB.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets he.mar)
 (deps    (:x he.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets he_IL.mar)
 (deps    (:x he_IL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hi.mar)
 (deps    (:x hi.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hi_IN.mar)
 (deps    (:x hi_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hi__DIRECT.mar)
 (deps    (:x hi__DIRECT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hr.mar)
 (deps    (:x hr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hr_HR.mar)
 (deps    (:x hr_HR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hu.mar)
 (deps    (:x hu.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hu_HU.mar)
 (deps    (:x hu_HU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hy.mar)
 (deps    (:x hy.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hy_AM.mar)
 (deps    (:x hy_AM.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets hy_AM_REVISED.mar)
 (deps    (:x hy_AM_REVISED.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets id.mar)
 (deps    (:x id.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets id_ID.mar)
 (deps    (:x id_ID.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets index.mar)
 (deps    (:x index.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets is.mar)
 (deps    (:x is.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets is_IS.mar)
 (deps    (:x is_IS.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets it.mar)
 (deps    (:x it.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets it_CH.mar)
 (deps    (:x it_CH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets it_IT.mar)
 (deps    (:x it_IT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets it_IT_PREEURO.mar)
 (deps    (:x it_IT_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets iw.mar)
 (deps    (:x iw.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets iw_IL.mar)
 (deps    (:x iw_IL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ja.mar)
 (deps    (:x ja.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ja_JP.mar)
 (deps    (:x ja_JP.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ka.mar)
 (deps    (:x ka.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ka_GE.mar)
 (deps    (:x ka_GE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kk.mar)
 (deps    (:x kk.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kk_KZ.mar)
 (deps    (:x kk_KZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kl.mar)
 (deps    (:x kl.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kl_GL.mar)
 (deps    (:x kl_GL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kn.mar)
 (deps    (:x kn.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kn_IN.mar)
 (deps    (:x kn_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ko.mar)
 (deps    (:x ko.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ko_KR.mar)
 (deps    (:x ko_KR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kok.mar)
 (deps    (:x kok.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kok_IN.mar)
 (deps    (:x kok_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kw.mar)
 (deps    (:x kw.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets kw_GB.mar)
 (deps    (:x kw_GB.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ky.mar)
 (deps    (:x ky.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ky_KG.mar)
 (deps    (:x ky_KG.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets lt.mar)
 (deps    (:x lt.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets lt_LT.mar)
 (deps    (:x lt_LT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets lv.mar)
 (deps    (:x lv.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets lv_LV.mar)
 (deps    (:x lv_LV.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mk.mar)
 (deps    (:x mk.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mk_MK.mar)
 (deps    (:x mk_MK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mn.mar)
 (deps    (:x mn.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mn_MN.mar)
 (deps    (:x mn_MN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mr.mar)
 (deps    (:x mr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mr_IN.mar)
 (deps    (:x mr_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ms.mar)
 (deps    (:x ms.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ms_BN.mar)
 (deps    (:x ms_BN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ms_MY.mar)
 (deps    (:x ms_MY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mt.mar)
 (deps    (:x mt.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets mt_MT.mar)
 (deps    (:x mt_MT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nb.mar)
 (deps    (:x nb.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nb_NO.mar)
 (deps    (:x nb_NO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nl.mar)
 (deps    (:x nl.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nl_BE.mar)
 (deps    (:x nl_BE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nl_BE_PREEURO.mar)
 (deps    (:x nl_BE_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nl_NL.mar)
 (deps    (:x nl_NL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nl_NL_PREEURO.mar)
 (deps    (:x nl_NL_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nn.mar)
 (deps    (:x nn.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets nn_NO.mar)
 (deps    (:x nn_NO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets no.mar)
 (deps    (:x no.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets no_NO.mar)
 (deps    (:x no_NO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets no_NO_NY.mar)
 (deps    (:x no_NO_NY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets om.mar)
 (deps    (:x om.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets om_ET.mar)
 (deps    (:x om_ET.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets om_KE.mar)
 (deps    (:x om_KE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pa.mar)
 (deps    (:x pa.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pa_IN.mar)
 (deps    (:x pa_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pl.mar)
 (deps    (:x pl.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pl_PL.mar)
 (deps    (:x pl_PL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pt.mar)
 (deps    (:x pt.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pt_BR.mar)
 (deps    (:x pt_BR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pt_PT.mar)
 (deps    (:x pt_PT.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets pt_PT_PREEURO.mar)
 (deps    (:x pt_PT_PREEURO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ro.mar)
 (deps    (:x ro.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ro_RO.mar)
 (deps    (:x ro_RO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets root.mar)
 (deps    (:x root.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ru.mar)
 (deps    (:x ru.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ru_RU.mar)
 (deps    (:x ru_RU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ru_UA.mar)
 (deps    (:x ru_UA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sa.mar)
 (deps    (:x sa.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sa_IN.mar)
 (deps    (:x sa_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sh.mar)
 (deps    (:x sh.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sh_YU.mar)
 (deps    (:x sh_YU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sk.mar)
 (deps    (:x sk.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sk_SK.mar)
 (deps    (:x sk_SK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sl.mar)
 (deps    (:x sl.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sl_SI.mar)
 (deps    (:x sl_SI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets so.mar)
 (deps    (:x so.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets so_DJ.mar)
 (deps    (:x so_DJ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets so_ET.mar)
 (deps    (:x so_ET.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets so_KE.mar)
 (deps    (:x so_KE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets so_SO.mar)
 (deps    (:x so_SO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sq.mar)
 (deps    (:x sq.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sq_AL.mar)
 (deps    (:x sq_AL.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sr.mar)
 (deps    (:x sr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sr_YU.mar)
 (deps    (:x sr_YU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sv.mar)
 (deps    (:x sv.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sv_FI.mar)
 (deps    (:x sv_FI.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sv_SE.mar)
 (deps    (:x sv_SE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sw.mar)
 (deps    (:x sw.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sw_KE.mar)
 (deps    (:x sw_KE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets sw_TZ.mar)
 (deps    (:x sw_TZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets syr.mar)
 (deps    (:x syr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets syr_SY.mar)
 (deps    (:x syr_SY.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ta.mar)
 (deps    (:x ta.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ta_IN.mar)
 (deps    (:x ta_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets te.mar)
 (deps    (:x te.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets te_IN.mar)
 (deps    (:x te_IN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets test_1.mar)
 (deps    (:x test_1.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets th.mar)
 (deps    (:x th.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets th_TH.mar)
 (deps    (:x th_TH.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ti.mar)
 (deps    (:x ti.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ti_ER.mar)
 (deps    (:x ti_ER.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ti_ET.mar)
 (deps    (:x ti_ET.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets tr.mar)
 (deps    (:x tr.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets tr_TR.mar)
 (deps    (:x tr_TR.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets tt.mar)
 (deps    (:x tt.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets tt_RU.mar)
 (deps    (:x tt_RU.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets uk.mar)
 (deps    (:x uk.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets uk_UA.mar)
 (deps    (:x uk_UA.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ur.mar)
 (deps    (:x ur.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets ur_PK.mar)
 (deps    (:x ur_PK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets uz.mar)
 (deps    (:x uz.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets uz_UZ.mar)
 (deps    (:x uz_UZ.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets vi.mar)
 (deps    (:x vi.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets vi_VN.mar)
 (deps    (:x vi_VN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh.mar)
 (deps    (:x zh.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_CN.mar)
 (deps    (:x zh_CN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_HK.mar)
 (deps    (:x zh_HK.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_MO.mar)
 (deps    (:x zh_MO.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_SG.mar)
 (deps    (:x zh_SG.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_TW.mar)
 (deps    (:x zh_TW.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh_TW_STROKE.mar)
 (deps    (:x zh_TW_STROKE.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))


(rule
 (targets zh__PINYIN.mar)
 (deps    (:x zh__PINYIN.txt) (alias database))
 (action  (chdir .. (run tools/camomilelocaledef.exe --file %{x} locales))))

